@@ -24,8 +24,12 @@ class KCE():
             print(i)
 
 
-    def help(self, function):
-        if function in list(self.function_description.keys()):
-            print(self.function_description[function])
+    def help(self, order):
+        if len(list(self.function_description.keys())) >= int(order)+1 > 0:
+            print(self.function_description[list(self.function_description.keys())[int(order)-1]])
         else:
-            print("그런 함수는 없습니다.")
\ No newline at end of file
+            print("범위를 넘어섰습니다.")
+
+if __name__ == "__main__":
+    CS = KCE()
+    CS.help(1)
\ No newline at end of file
